@@ -1,8 +1,9 @@
-from .pq import Pipeline, _import_global
+from .pq import Pipeline, _import_global, JSONItemList
 import json, sys, os
 import argparse
 
 
+
 def main():
     parser = argparse.ArgumentParser(
         description="pq is a Python command-line JSON processor"
@@ -23,8 +24,8 @@ def main():
     if args.imports:
         _import_global(args.imports)
 
-    json_data = json.loads(sys.stdin.read())
 
-    pipeline = Pipeline(jsondata=json_data, str_input=args.expression)
+
+    pipeline = Pipeline(json_stream=sys.stdin, str_input=args.expression)
 
     pipeline.run()
